@@ -1,10 +1,14 @@
 
-# Functions
+# Constants
 from .constants import *
+from .colors import *
+# Functions
 from .auxiliary import *
 from .parsers import *
 from .stats import *
 from .files import *
+from .plots import *
+from .plotsAux import *
 # Classes
 # from .History import *
 from .Battle import *
