@@ -32,7 +32,7 @@ CLR_STATS = {
 }
 # Markers/Colors for match types
 MKR_MT = {
-    'Turf War':             '-',
+    'Turf War':             ',',
     'Rainmaker':            '1',
     'Splat Zones':          '2',
     'Clam Blitz':           '3',
@@ -40,14 +40,14 @@ MKR_MT = {
     'Tricolor Turf War':    '.'
 }
 CLR_MT = {
-    'Turf War':             clr.BLUE_V_GREEN_S2[0],
+    'Turf War':             clr.LMODEL_V_PMODEL_S2[-1],
     'Rainmaker':            clr.WINNERW_V_WOUTERW_S2[2],
     'Splat Zones':          clr.BLUE_V_GREEN_S2[2],
     'Clam Blitz':           clr.RPURPLE_V_GAPPLE_S2[0],
     'Tower Control':        clr.PINK_V_GREEN_S1 [0],
     'Tricolor Turf War':    clr.PINK_V_GREEN_S1 [0]  
 }
-CLR_PAINT = clr.EATIT_V_SAVEIT_S2[0]
+CLR_PAINT = clr.TURQUOISE_V_PUMPKIN_S2[-1]
 # Colors for scatter elements
 CLR_WL = {
     'W': clr.SKY_V_GOLD_S2[0],
@@ -59,17 +59,40 @@ MKR_WL = {
 }
 MKR_KO = {
     True: '.',
-    False: '-'    
+    False: ','    
 }
 CLR_KO = {
     True: clr.SKY_V_GOLD_S2[0],
-    False: clr.LBLUE_V_FUCHSIA_S2[1]
+    False: clr.LMODEL_V_PMODEL_S2[-1]
 }
 MKR_FEST = {
     True: '.',
-    False: '-'
+    False: ','
 }
 CLR_FEST = {
     True: clr.PINK_V_GREEN_S1 [0],
-    False: clr.PINK_V_GREEN_S1 [0]
-}
\ No newline at end of file
+    False: clr.LMODEL_V_PMODEL_S2[-1]
+}
+CLR_STAGE = {
+    'Inkblot Art Academy': clr.LPINK_V_BLUE_S2[0],
+    'Hagglefish Market': clr.LPINK_V_BLUE_S2[1],
+    'MakoMart': clr.PINK_V_GREEN_S1[2],
+    'Eeltail Alley': clr.PINK_V_ORANGE_S1[1],
+    'Wahoo World': clr.PINK_V_ORANGE_S1[2],
+    'Undertow Spillway': clr.RASPBERRY_V_NYELLOW_S2[1],
+    'Mahi-Mahi Resort': clr.CHAOS_V_ORDER_S2[1],
+    'Hammerhead Bridge': clr.MAYO_V_KETCHUP_S2[1],
+    'Sturgeon Shipyard': clr.VAMPIRE_V_WEREWOLF_S2[2],
+    'Mincemeat Metalworks': clr.TSUBUAN_V_KOSHIAN_S2[1],
+    "Museum d'Alfonsino": clr.SALTY_V_SWEET_S2[0],
+    'Scorch Gorge': clr.UNICORN_V_NARWHAL_S2[0]
+}
+CLR_CLS_LONG = [
+    clr.LPINK_V_BLUE_S2[0], clr.LPINK_V_BLUE_S2[1],
+    clr.NPINK_V_NGREEN_S2[1], 
+    clr.RASPBERRY_V_NYELLOW_S2[1],
+    clr.WINNERW_V_WOUTERW_S2[0], clr.WINNERW_V_WOUTERW_S2[1], clr.WINNERW_V_WOUTERW_S2[2],
+    clr.TSUBUAN_V_KOSHIAN_S2[1],
+    clr.FAM_V_FRIEND_S2[1],
+    clr.GRAPE_V_TURQUOISE_S2[0], clr.GRAPE_V_TURQUOISE_S2[1]
+]
\ No newline at end of file
